@@ -20,11 +20,11 @@
 
 #include "freebusyitemmodel.h"
 
-
 #include <Akonadi/Calendar/FreeBusyManager>
 
-#include <KLocale>
+#include <KLocalizedString>
 
+#include <QLocale>
 #include <QTimerEvent>
 
 using namespace CalendarSupport;
@@ -76,37 +76,40 @@ public:
 
 private:
     QList<ItemPrivateData *> childItems;
-    ItemPrivateData *parentItem;
+    ItemPrivateData *parentItem = nullptr;
 };
 
 class CalendarSupport::FreeBusyItemModelPrivate
 {
 public:
     FreeBusyItemModelPrivate()
-        : mForceDownload(false),
-          mRootData(nullptr)
+        : mForceDownload(false)
+        , mRootData(nullptr)
     {
     }
+
     ~FreeBusyItemModelPrivate()
     {
         delete mRootData;
     }
 
     QTimer mReloadTimer;
-    bool mForceDownload;
+    bool mForceDownload = false;
     QList<FreeBusyItem::Ptr> mFreeBusyItems;
-    ItemPrivateData *mRootData;
+    ItemPrivateData *mRootData = nullptr;
 };
 
 FreeBusyItemModel::FreeBusyItemModel(QObject *parent)
-    : QAbstractItemModel(parent), d(new CalendarSupport::FreeBusyItemModelPrivate)
+    : QAbstractItemModel(parent)
+    , d(new CalendarSupport::FreeBusyItemModelPrivate)
 {
     qRegisterMetaType<KCalCore::Attendee::Ptr>("KCalCore::Attendee::Ptr");
     qRegisterMetaType<KCalCore::FreeBusy::Ptr>("KCalCore::FreeBusy::Ptr");
     qRegisterMetaType<KCalCore::Period>("KCalCore::Period");
 
     Akonadi::FreeBusyManager *m = Akonadi::FreeBusyManager::self();
-    connect(m, &Akonadi::FreeBusyManager::freeBusyRetrieved, this, &FreeBusyItemModel::slotInsertFreeBusy);
+    connect(m, &Akonadi::FreeBusyManager::freeBusyRetrieved, this,
+            &FreeBusyItemModel::slotInsertFreeBusy);
 
     connect(&d->mReloadTimer, &QTimer::timeout, this, &FreeBusyItemModel::autoReload);
     d->mReloadTimer.setSingleShot(true);
@@ -125,7 +128,7 @@ QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    ItemPrivateData *data = (ItemPrivateData *) index.internalPointer();
+    ItemPrivateData *data = (ItemPrivateData *)index.internalPointer();
 
     if (data->parent() == d->mRootData) {
         int row = index.row();
@@ -158,7 +161,8 @@ QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
     switch (role) {
     case Qt::DisplayRole: // return something to make modeltest happy
         return QStringLiteral("%1 - %2").
-               arg(KLocale::global()->formatDateTime(period.start()), KLocale::global()->formatDateTime(period.end()));
+               arg(QLocale().toString(period.start().toLocalTime(), QLocale::ShortFormat),
+                   QLocale().toString(period.end().toLocalTime(), QLocale::ShortFormat));
     case FreeBusyItemModel::FreeBusyPeriodRole:
         return QVariant::fromValue(period);
     default:
@@ -168,7 +172,7 @@ QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
 
 int FreeBusyItemModel::rowCount(const QModelIndex &parent) const
 {
-    ItemPrivateData *parentData;
+    ItemPrivateData *parentData = nullptr;
     if (parent.column() > 0) {
         return 0;
     }
@@ -194,7 +198,7 @@ QModelIndex FreeBusyItemModel::index(int row, int column, const QModelIndex &par
         return QModelIndex();
     }
 
-    ItemPrivateData *parentData;
+    ItemPrivateData *parentData = nullptr;
     if (!parent.isValid()) {
         parentData = d->mRootData;
     } else {
@@ -249,7 +253,7 @@ void FreeBusyItemModel::addItem(const FreeBusyItem::Ptr &freebusy)
 }
 
 void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent,
-        const KCalCore::FreeBusyPeriod::List &list)
+                                           const KCalCore::FreeBusyPeriod::List &list)
 {
     if (!parent.isValid()) {
         return;
@@ -369,8 +373,7 @@ void FreeBusyItemModel::timerEvent(QTimerEvent *event)
     }
 }
 
-void FreeBusyItemModel::slotInsertFreeBusy(const KCalCore::FreeBusy::Ptr &fb,
-        const QString &email)
+void FreeBusyItemModel::slotInsertFreeBusy(const KCalCore::FreeBusy::Ptr &fb, const QString &email)
 {
     if (!fb) {
         return;
@@ -420,8 +423,3 @@ void FreeBusyItemModel::cancelReload()
     d->mReloadTimer.stop();
 }
 
-void FreeBusyItemModel::manualReload()
-{
-    d->mForceDownload = true;
-    reload();
-}
